..
    DO NOT DELETE! This causes _autosummary to generate stub files

casm package
============

.. autosummary::
    :toctree: _autosummary
    :template: custom-module-template.rst
    :recursive:

    casm.bset
